@@ -16,19 +16,14 @@ from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from matplotlib.cm import jet
 from pygame.mixer import Sound, init, quit, get_init, set_num_channels
 
-def AE_install():
+def AE_download():
 	AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
-	if len(os.listdir(AE_path)) < 3073:
+	if not os.path.isdir(AE_path):
 		print('Cloning the audio engine to the pyanthem package directory...')
 		Repo.clone_from('https://github.com/nicthib/AE.git',AE_path)
 		print('Audio engine downloaded to {}'.format(AE_path))
 	else:
-		print('Audio engine is already present in {}'.format(AE_path))
-
-def AE_uninstall():
-	AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
-	os.remove(AE_path)
-	print('Audio engine uninstalled.')
+		print('Audio engine is already present in {}. If you want to uninstall, you must manually delete the AE folder.'.format(AE_path))
 
 def init_entry(fn):
 	if isinstance(fn, str):
@@ -46,10 +41,10 @@ class GUI(Tk):
 			AE_path = r'C:\Users\dnt21\AppData\Local\Programs\Python\Python37-32\Lib\site-packages\pyanthem\AE'
 		else:
 			AE_path = os.path.join(os.path.split(os.path.realpath(__file__))[0],'AE')
-		if len(os.listdir(AE_path)) < 3073:
-			self.AE_run = False
-		else:
+		if os.path.isdir(AE_path):
 			self.AE_run = True
+		else:
+			self.AE_run = False
 		self.initGUI()
 	
 	def donothing(self):
@@ -322,7 +317,7 @@ class GUI(Tk):
 			self.audio_fmt_opts = ['Stream','Piano','MIDI']
 		else:
 			self.audio_fmt_opts = ['Stream','MIDI']
-			self.status['text'] = 'Status: AE engine not initialized. Please do using AE_init() to enable "Piano" format'
+			self.status['text'] = 'Status: AE engine not downloaded. Please do using AE_download() to enable "Piano" format'
 
 		# Option Menus
 		OptionMenu(self,self.oct_add,*self.oct_add_opts).grid(row=2, column=6, sticky='W')
